==> harp-0.2.10.tar.gz: harp-0.2.10/pkg/sdk/fsutil/builder.go <==
// Licensed to Elasticsearch B.V. under one or more contributor
// license agreements. See the NOTICE file distributed with
// this work for additional information regarding copyright
// ownership. Elasticsearch B.V. licenses this file to you under
// the Apache License, Version 2.0 (the "License"); you may
// not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package fsutil

import (
	"errors"
	"fmt"
	"io/fs"
	"os"
	"path/filepath"
	"strings"

	"github.com/elastic/harp/pkg/sdk/fsutil/targzfs"
)

var (
	ErrNotSupported = errors.New("not supported filesystem path")
)

func From(rootPath string) (fs.FS, error) {
	// Get absolute path
	absPath, errPath := filepath.Abs(rootPath)
	if errPath != nil {
		return nil, fmt.Errorf("unable to get absolute path: %w", errPath)
	}

	// Check existence
	fi, errFileInfo := os.Stat(absPath)
	if errFileInfo != nil {
		return nil, fmt.Errorf("unabe to retrieve file information: %w", errFileInfo)
	}

	var (
		errRootFS  error
		fileRootFS fs.FS
	)
	switch {
	case !fi.IsDir() && strings.HasSuffix(absPath, ".tar.gz"):
		// Create in-memory filesystem.
		fileRootFS, errRootFS = targzfs.FromFile(absPath)
	case fi.IsDir():
		fileRootFS = os.DirFS(absPath)
	default:
		errRootFS = ErrNotSupported
	}
	if errRootFS != nil {
		return nil, fmt.Errorf("unable to prepare filesystem: %w", errRootFS)
	}

	// No error
	return fileRootFS, nil
}

==> harp-0.2.11.tar.gz: harp-0.2.11/pkg/sdk/fsutil/builder.go <==
// Licensed to Elasticsearch B.V. under one or more contributor
// license agreements. See the NOTICE file distributed with
// this work for additional information regarding copyright
// ownership. Elasticsearch B.V. licenses this file to you under
// the Apache License, Version 2.0 (the "License"); you may
// not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package fsutil

import (
	"errors"
	"fmt"
	"io/fs"
	"os"
	"path/filepath"
	"strings"

	"github.com/elastic/harp/pkg/sdk/fsutil/targzfs"
)

var ErrNotSupported = errors.New("not supported filesystem path")

func From(rootPath string) (fs.FS, error) {
	// Get absolute path
	absPath, errPath := filepath.Abs(rootPath)
	if errPath != nil {
		return nil, fmt.Errorf("unable to get absolute path: %w", errPath)
	}

	// Check existence
	fi, errFileInfo := os.Stat(absPath)
	if errFileInfo != nil {
		return nil, fmt.Errorf("unabe to retrieve file information: %w", errFileInfo)
	}

	var (
		errRootFS  error
		fileRootFS fs.FS
	)
	switch {
	case !fi.IsDir() && strings.HasSuffix(absPath, ".tar.gz"):
		// Create in-memory filesystem.
		fileRootFS, errRootFS = targzfs.FromFile(absPath)
	case fi.IsDir():
		fileRootFS = os.DirFS(absPath)
	default:
		errRootFS = ErrNotSupported
	}
	if errRootFS != nil {
		return nil, fmt.Errorf("unable to prepare filesystem: %w", errRootFS)
	}

	// No error
	return fileRootFS, nil
}
